hawksoft-md2zhihu Package
=========================

This is a simple package which can comvert markdown file with latex
formula to zhihu website docs.
 ## 1 install 
 pip install  hawksoft-md2zhihu ## 2 usage Installation will add a new command line:
md2zhihu. you can use it like this: md2zhihu sourceFilename
destineFilename or md2zhihu sourceFilename destineDirectory the command
will create a new file which can be imported to zhihu website.
